2025-09-17 Version: 2.0.3
- Generated python 2021-09-03 for appstream-center.

2025-06-23 Version: 2.0.2
- Update API GetConnectionTicket: add request parameters AppPolicyId.


2025-04-07 Version: 2.0.1
- Update API GetConnectionTicket: add request parameters AccessType.


2025-03-19 Version: 2.0.0
- Support API ResetAppResources.
- Support API RestartAppResources.
- Support API StartAppResources.
- Support API StopAppResources.
- Delete API ListLFUApp.
- Update API GetConnectionTicket: add param AutoConnectInQueue.
- Update API GetConnectionTicket: add param ClientType.
- Update API GetConnectionTicket: add param EnvironmentConfig.
- Update API GetConnectionTicket: update param ConnectionProperties.
- Update API GetConnectionTicket: update response param.


2024-10-10 Version: 1.0.1
- Update API GetConnectionTicket: update response param.


2024-07-03 Version: 1.0.0
- Generated python 2021-09-03 for appstream-center.

